pub fn xml_root_local_name(
bytes: &[u8],
policy: XmlSafetyPolicy,
) -> Result<String, XmlSafetyError>Expand description
Returns the local name of a validated document root.
pub fn xml_root_local_name(
bytes: &[u8],
policy: XmlSafetyPolicy,
) -> Result<String, XmlSafetyError>Returns the local name of a validated document root.