pub struct ValidatedXml(/* private fields */);Expand description
A cheap-to-clone, validated XML document retaining the exact original bytes.
Implementations
Sourceimpl ValidatedXml
impl ValidatedXml
Sourcepub fn new(bytes: impl Into<Arc<[u8]>>) -> Result<Self, Error>
pub fn new(bytes: impl Into<Arc<[u8]>>) -> Result<Self, Error>
Validates and owns XML bytes under the default untrusted-input policy.
Errors
Returns an error when the bytes violate the default XML safety or well-formedness contract.
Sourcepub fn with_policy(
bytes: impl Into<Arc<[u8]>>,
policy: XmlSafetyPolicy,
) -> Result<Self, Error>
pub fn with_policy( bytes: impl Into<Arc<[u8]>>, policy: XmlSafetyPolicy, ) -> Result<Self, Error>
Validates and owns XML bytes under policy.
Errors
Returns an error when policy is invalid or the bytes violate a configured safety or
well-formedness rule.
Sourcepub fn from_reader<R: Read>(reader: R) -> Result<Self, Error>
pub fn from_reader<R: Read>(reader: R) -> Result<Self, Error>
Reads, validates, and owns XML under the default untrusted-input policy.
Errors
Returns an error when reading fails or the input violates the default XML safety or well-formedness contract.
pub fn as_bytes(&self) -> &[u8] ⓘ
pub fn document(&self) -> &OwnedDocument