XmlSafetyPolicy

Struct XmlSafetyPolicy 

pub struct XmlSafetyPolicy {
    pub max_input_bytes: usize,
    pub max_depth: usize,
    pub max_elements: usize,
    pub max_attributes_per_element: usize,
    pub max_text_bytes: usize,
    pub max_events: usize,
    pub reject_doctype: bool,
}
Finite resource and declaration limits applied to untrusted XML.

Fields

max_input_bytes: usizemax_depth: usizemax_elements: usizemax_attributes_per_element: usizemax_text_bytes: usizemax_events: usizereject_doctype: bool

Implementations

Source

impl XmlSafetyPolicy

pub const fn untrusted() -> Self

A conservative policy suitable for network and storage protocol input.